==> nuiton-utils-1.1.0-sources.jar: org/nuiton/util/URIConverter.java <==
/* *##% Nuiton utilities library
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%* */
package org.nuiton.util;

import org.apache.commons.beanutils.ConversionException;
import static org.apache.commons.logging.LogFactory.getLog;
import static org.nuiton.i18n.I18n._;

import java.net.URI;
import java.net.URISyntaxException;
import org.apache.commons.beanutils.Converter;

/**
 * classe pour convertir une chaine en un objet URI.
 *
 * @author chemit
 */
public class URIConverter implements Converter {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static org.apache.commons.logging.Log log = getLog(URIConverter.class);

    @Override
    public Object convert(Class aClass, Object value) {
        if (value == null) {
            throw new ConversionException(_("lutinutil.error.convertor.noValue", this));
        }
        if (isEnabled(aClass)) {
            Object result;
            if (isEnabled(value.getClass())) {
                result = value;
                return result;
            }
            if (value instanceof String) {
                result = valueOf((String) value);
                return result;
            }
        }
        throw new ConversionException(_("lutinutil.error.no.convertor", aClass.getName(), value));
    }

    protected URI valueOf(String value) {
        try {
            URI result;
            result = new URI(value);
            return result;
        } catch (URISyntaxException e) {
            throw new ConversionException(_("lutinutil.error.url.convertor", value, this, e.getMessage()));
        }
    }

    public URIConverter() {
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
    }

    protected boolean isEnabled(Class<?> aClass) {
        return aClass == URI.class;
    }

    public Class<?> getType() {
        return URI.class;
    }
}

==> nuiton-utils-1.1.5-sources.jar: org/nuiton/util/URIConverter.java <==
/* *##% Nuiton utilities library
 * Copyright (C) 2004 - 2009 CodeLutin
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Lesser Public License for more details.
 *
 * You should have received a copy of the GNU General Lesser Public
 * License along with this program.  If not, see
 * <http://www.gnu.org/licenses/lgpl-3.0.html>. ##%* */
package org.nuiton.util;

import org.apache.commons.beanutils.ConversionException;
import static org.apache.commons.logging.LogFactory.getLog;
import static org.nuiton.i18n.I18n._;

import java.net.URI;
import java.net.URISyntaxException;
import org.apache.commons.beanutils.Converter;

/**
 * classe pour convertir une chaine en un objet URI.
 *
 * @author chemit
 */
public class URIConverter implements Converter {

    /** to use log facility, just put in your code: log.info(\"...\"); */
    static org.apache.commons.logging.Log log = getLog(URIConverter.class);

    @Override
    public Object convert(Class aClass, Object value) {
        if (value == null) {
            throw new ConversionException(_("nuitonutil.error.convertor.noValue", this));
        }
        if (isEnabled(aClass)) {
            Object result;
            if (isEnabled(value.getClass())) {
                result = value;
                return result;
            }
            if (value instanceof String) {
                result = valueOf((String) value);
                return result;
            }
        }
        throw new ConversionException(_("nuitonutil.error.no.convertor", aClass.getName(), value));
    }

    protected URI valueOf(String value) {
        try {
            URI result;
            result = new URI(value);
            return result;
        } catch (URISyntaxException e) {
            throw new ConversionException(_("nuitonutil.error.url.convertor", value, this, e.getMessage()));
        }
    }

    public URIConverter() {
        if (log.isDebugEnabled()) {
            log.debug(this);
        }
    }

    protected boolean isEnabled(Class<?> aClass) {
        return aClass == URI.class;
    }

    public Class<?> getType() {
        return URI.class;
    }
}
